from setuptools import setup

setup(
    name="freefiregen",
    version="2.0.0",
    url="https://github.com/m2-byte/freefiregen",
    author="m2_byte",
    author_email="mtwobyte@gmail.com",
    description="Python library for generating and managing Free Fire guest accounts programmatically.",
    packages=["freefiregen"],
    package_data={"freefiregen": ["*.pyd"]},  # يستخدم .pyd الموجود
    zip_safe=False,
    python_requires=">=3.8",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "Topic :: Software Development :: Libraries",
    ],
)
